@@ -1,8 +1,8 @@
-__version__ = '0.3.3'
+__version__ = '0.3.5'
 
 import random
 from termcolor import colored, cprint
-
+import platform
 import time
 from art import *
 import os
@@ -17,8 +17,12 @@ vars = variables()
 colors = vars.colors
 cases = vars.scheme
 title = vars.title
-
-
+commands = {"Windows": ["cls", "exit"], "Linux":["clear", """
+        osascript -e 'tell application "Terminal" to close first window' && exit
+        """], "Darwin": ["clear", """
+        osascript -e 'tell application "Terminal" to close first window' && exit
+        """] }
+sys = platform.system()
 
 global grid1
 global grid2
@@ -66,20 +70,6 @@ def getCoup(p, casesDispo) -> int:
     return coup 
     
     
-    
-    """
-    #print(casesDispo) 
-    coup = input(f'{p}, quelle case veux-tu marquer ?  ')
-    try:
-        coup = int(coup)
-        if str(coup) in str(casesDispo):
-            return coup
-        else:
-            print('Choisi une case disponible (numéros visibles)')
-            return getCoup(p, casesDispo)
-    except ValueError:
-        print('Choisi un des nombres disponible (numéros visibles)')
-        getCoup(p, casesDispo)"""
 
 
 def setGame(joueurs, gameManager):
@@ -87,7 +77,7 @@ def setGame(joueurs, gameManager):
     for p in gameManager['currentPlayers']:
         joueurs.append(p)
     grid = setGrid(1, 0, 0)
-    os.system('clear')
+    os.system(commands[sys][0])
     for ligne in grid:
         print(ligne)
     game(joueurs, gameManager)
@@ -118,14 +108,14 @@ def game(joueurs, gameManager):
             newGrid = setGrid(turn, coup, Player1)
         else:
             newGrid = setGrid(turn, coup, Player2)
-        os.system('clear')
+        os.system(commands[sys][0])
         for ligne in newGrid:
             print(ligne)
 
 
 
     time.sleep(2)
-    os.system('clear')
+    os.system(commands[sys][0])
     tprint('Game over')
     """print(p)
     print(type(p))
@@ -179,14 +169,12 @@ def game(joueurs, gameManager):
             return endGameChoice()
     mode = int(endGameChoice())
     if mode == 1:
-        os.system("""
-        osascript -e 'tell application "Terminal" to close first window' && exit
-        """)
+        os.system(commands[sys][1])
     elif mode == 2:
         setGame([], gameManager)
 
     elif mode ==3 :
-        os.system('clear')
+        os.system(commands[sys][0])
         players = []
         temp = getPlayers()
         for p in temp.keys():
@@ -198,9 +186,9 @@ def game(joueurs, gameManager):
 
 if __name__ == "__main__":
     loading()
-    os.system('clear')
+    os.system(commands[sys][0])
     #pathToScript = os.path.dirname(os.path.abspath(__file__))
     #print(pathToScript)
-    gameManager = getPlayers()
+    gameManager = getPlayers(pathToScript)
     setGame(joueurs, gameManager)
     
